@@ -53,6 +53,20 @@ pub fn builtin_verbs() -> Vec<Verb> {
     vec![
         internal(back),
 
+        // input actions, not visible in doc, but available for
+        // exemple in remote control
+        internal(input_clear).no_doc(),
+        internal(input_del_char_left).no_doc(),
+        internal(input_del_char_below).no_doc(),
+        internal(input_del_word_left).no_doc(),
+        internal(input_del_word_right).no_doc(),
+        internal(input_go_to_end).no_doc(),
+        internal(input_go_left).no_doc(),
+        internal(input_go_right).no_doc(),
+        internal(input_go_to_start).no_doc(),
+        internal(input_go_word_left).no_doc(),
+        internal(input_go_word_right).no_doc(),
+
         // those two operations are mapped on ALT-ENTER, one
         // for directories and the other one for the other files
         external("cd", "cd {directory}", FromParentShell)
@@ -186,6 +200,16 @@ pub fn builtin_verbs() -> Vec<Verb> {
             .with_control_key('q')
             .with_shortcut("q"),
         internal(refresh).with_key(F5),
+        internal(root_up)
+            .with_key(KeyEvent {
+                code: KeyCode::Up,
+                modifiers: KeyModifiers::CONTROL,
+            }),
+        internal(root_down)
+            .with_key(KeyEvent {
+                code: KeyCode::Down,
+                modifiers: KeyModifiers::CONTROL,
+            }),
         internal(select_first).with_key(HOME),
         internal(select_last).with_key(END),
         internal(clear_stage).with_shortcut("cls"),
